.. _api_analyse_hic:

===================================
Analyse Hi-C matrices using the API
===================================

In :ref:`analyse_hic` we analysed a Hi-C matrix using command line tools. Here,
we will accomplish the same using only the Python API.

.. toctree::
   :maxdepth: 1

   Expected values and O/E matrices <analyse/oe>
   AB compartments <analyse/compartments>
   PCA analysis <analyse/pca>
   TADs and TAD boundaries <analyse/domains>
   Matrix and score comparisons <analyse/comparisons>
   Aggregate analysis <analyse/aggregate>
   Loop calling <analyse/loops>
